from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # Source: https://learnenglish100.com/grammar/career-job/
    jobs = (
        "أحيائي",
        "احصائي",
        "اطفائي",
        "بائع",
        "بائع خضار وفاكهة",
        "بائع زهور",
        "بائعة",
        "بواب",
        "تاجر",
        "جزار",
        "جوھري",
        "جيولوجي",
        "حداد",
        "حلاق",
        "خادمة",
        "خباز",
        "خبير اقتصادي",
        "خبير في التراث الشعبي",
        "خبير في عالم الحيوان",
        "خراط",
        "خياط",
        "خياطة",
        "داية",
        "رئيس طهاه",
        "راقصة",
        "راقصة باليه",
        "رجل مباحث",
        "رسام",
        "روائي",
        "سائق",
        "سائق تاكسي",
        "سائق شاحنة",
        "ساعاتي",
        "ساعي بريد",
        "سكرتير",
        "سكرتيرة",
        "سمكري",
        "سياسي",
        "شاعر",
        "شرطي",
        "صائغ",
        "صاحب متجر",
        "صاحب مطبعة",
        "صاحب مكتبة",
        "صانع أدوات بصرية",
        "صباغ",
        "صباغ أحذية",
        "صحافي",
        "صحفي",
        "صراف",
        "صيدلي",
        "ضابط شرطة",
        "ضارب على الآلة الكاتبة",
        "طباخ",
        "طبيب",
        "طبيب أسنان",
        "طبيب جراح",
        "طبيب عيون",
        "طبيب نفساني",
        "طيار",
        "عارضة أزياء",
        "عالم",
        "عالم أرصاد جوية",
        "عالم اثار",
        "عالم رياضيات",
        "عالم فيزياء",
        "عامل",
        "عامل أحذية",
        "عامل بمتجر",
        "عامل بناء",
        "غسالة",
        "فنان",
        "فيلسوف",
        "قائد شرطة",
        "قاضي",
        "كاتب",
        "كاتب مسرحي",
        "لغوي",
        "مؤلف",
        "ماسح احذية",
        "مبرمج",
        "مترجم",
        "مجلد كتب",
        "محاسب",
        "محاضر",
        "محام",
        "محرر",
        "محرر جريدة",
        "مدير",
        "مدير او مخرج",
        "مدير بنك",
        "مدير تسويق",
        "مدير متجر",
        "مدير موظفين",
        "مذيع",
        "مساعد مبيعات",
        "مشتري",
        "مصحح قانوني",
        "مصصم",
        "مصفف شعر",
        "مصمم جرافيك",
        "مصمم ديكور",
        "مصور",
        "مضيفة جوية",
        "مضيفة في الطائرة",
        "مطرب",
        "معالج طبيعي",
        "معلم",
        "مغني",
        "مكوى",
        "ملحن",
        "ممثل",
        "ممثلة",
        "ممرضة",
        "منتج",
        "منجد",
        "منسق ازياء",
        "موزع جرائد",
        "موسيقار",
        "موصل طلبيات",
        "موظف استقبال",
        "موظف بدالة",
        "موظف حكومي",
        "ميكانيكي",
        "مھندس",
        "نادلة",
        "ناشر",
        "نباتي",
        "نجار",
        "نحات",
        "وسيط تأمين",
        "وكيل سفر",
        "وكيل عقارات",
    )
